Package: reconsi
Type: Package
Title: Resampling Collapsed Null Distributions for Simultaneous
        Inference
Version: 1.25.0
Authors@R: 
    c(person(given = "Stijn", family = "Hawinkel", 
    email = "stijn.hawinkel@psb.ugent.be", 
    role=c("cre", "aut"), comment = c(ORCID = "0000-0002-4501-5180")))
Description: Improves simultaneous inference under dependence of tests by
    estimating a collapsed null distribution through resampling. Accounting for 
    the dependence between tests increases the power while reducing the
    variability of the false discovery proportion. This dependence is common in
    genomics applications, e.g. when combining flow cytometry measurements with
    microbiome sequence counts. 
License: GPL-2
Encoding: UTF-8
RoxygenNote: 7.2.1
Imports: phyloseq, ks, reshape2, ggplot2, stats, methods, graphics,
        grDevices, matrixStats, Matrix
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
biocViews: Metagenomics, Microbiome, MultipleComparison, FlowCytometry
BugReports: https://github.com/CenterForStatistics-UGent/reconsi/issues
LazyData: true
git_url: https://git.bioconductor.org/packages/reconsi
git_branch: devel
git_last_commit: 1f35a62
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:37:14 UTC; biocbuild
Author: Stijn Hawinkel [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-4501-5180>)
Maintainer: Stijn Hawinkel <stijn.hawinkel@psb.ugent.be>
