# Generated by roxygen2: do not edit by hand

export(getApproxCovar)
export(getC1prop)
export(plotApproxCovar)
export(plotCovar)
export(plotNull)
export(reconsi)
export(testDAA)
exportMethods(testDAA)
import(ggplot2)
import(methods)
import(phyloseq)
importFrom(Matrix,nearPD)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,image)
importFrom(ks,dkde)
importFrom(ks,kde)
importFrom(ks,pkde)
importFrom(matrixStats,colRanks)
importFrom(matrixStats,weightedMean)
importFrom(reshape2,melt)
importFrom(stats,approx)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,ecdf)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,pwilcox)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,smooth.spline)
importFrom(stats,var)
