% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/F_estNormal.R
\name{estNormal}
\alias{estNormal}
\title{Fast estimation of mean and standard deviation of a normal distrbution,
optionally with weights}
\usage{
estNormal(y, w = NULL, p = length(y))
}
\arguments{
\item{y}{vector of observations}

\item{w}{optional weight vector}

\item{p}{The number of features}
}
\value{
A vector of length 2 with mean and standard deviation
}
\description{
Fast estimation of mean and standard deviation of a normal distrbution,
optionally with weights
}
